@@ -3,6 +3,8 @@ context("input tests")
 nanfile <- system.file("files/nancycats.xlsx", package = "popprxl")
 nanxc <- system.file("files/nancycats_extra_rows.xlsx", package = "popprxl")
 geox  <- system.file("files/geo_ex.xls", package = "popprxl")
+nit <- system.file("files/num_isolates_text.xlsx", package = "popprxl")
+nsg <- system.file("files/num_samp_greater.xlsx", package = "popprxl")
 
 data("nancycats", package = "adegenet")
 locNames(nancycats) <- locNames(nancycats)
@@ -21,6 +23,13 @@ test_that("Extra rows are detected", {
 	expect_identical(sort_alleles(nancycats), sort_alleles(nanx))
 })
 
+test_that("Characters in 2nd column are detected", {
+	expect_error(read.genalexcel(nit), "I found: 237u")
+})
+
+test_that("short data is rejected", {
+	expect_error(read.genalexcel(nsg))
+})
 test_that("Geographic data can be imported", {
 	geoxy <- read.genalexcel(geox, sheet = 1, geo = TRUE, genclone = FALSE)
 	geo   <- read.genalexcel(geox, sheet = 2, genclone = FALSE)
